package com.zgiot.zx.production.config;

import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;

/**
 * @des :  excel信息读取
 * @author: duyunbao
 * @email: 1114808306@qq.com
 * @date 2017/10/27 17:06
 **/
public class ReadExcel {
    private static final Logger logger = LoggerFactory.getLogger(ReadExcel.class);

    /**
     * 总行数
     */
    private int totalRows = 0;
    /**
     * 总条数
     */
    private int totalCells = 0;
    /**
     * 错误信息接收器
     */
    private String errorMsg;

    public ReadExcel() {
        super();
    }

    public int getTotalRows() {
        return totalRows;
    }

    public int getTotalCells() {
        return totalCells;
    }

    public String getErrorInfo() {//获取错误信息
        return errorMsg;
    }

    /***
     * @method_name: getExcelInfo
     * @des :  判断excel版本
     * @author: duyunbao
     * @param: [is, isExcel2003, wb]
     * @return: org.apache.poi.ss.usermodel.Workbook
     * @date: 2017/10/27 17:08
     **/
    private Workbook getExcelInfo(InputStream is, boolean isExcel2003, Workbook wb) {
        Workbook workbook =wb;
        try {
            /** 根据版本选择创建Workbook的方式 */
            //当excel是2003时
            if (isExcel2003) {
                workbook = new HSSFWorkbook(is);
            } else {//当excel是2007时
                workbook = new XSSFWorkbook(is);
            }
        } catch (IOException e) {
            logger.error(e.getMessage(),e);
        }
        return workbook;
    }



    /**
     *
     * @Title: encodeFileName
     * @Description: 导出文件转换文件名称编码
     * @param @param fileNames
     * @param @param request
     * @param @return    设定文件
     * @return String    返回类型
     * @throws
     */
    public static String encodeFileName(String fileNames , HttpServletRequest request) {
        String codedFilename = null;
        try {
            String agent = request.getHeader("USER-AGENT");
            if (null != agent && agent.contains("MSIE") || null != agent
                    && agent.contains("Trident") || null != agent && agent.contains("Edge")) {// ie浏览器及Edge浏览器
                String name = URLEncoder.encode(fileNames, "UTF-8");
                codedFilename = name;
            } else if (null != agent && agent.contains("Mozilla")) {// 火狐,Chrome等浏览器
                codedFilename = new String(fileNames.getBytes("UTF-8"), "iso-8859-1");
            }
        } catch (Exception e) {
            logger.error(e.getMessage(),e);
        }
        return codedFilename ;
    }

    public static String fileNameEncoding(String fileName, HttpServletRequest request)	throws IOException {
        String agent = request.getHeader("User-Agent");
        if (agent.contains("Firefox")) {
            /*BASE64Encoder base64Encoder = new BASE64Encoder();
            fileName = "=?utf-8?B?"
                    + base64Encoder.encode(fileName.getBytes("utf-8")) + "?=";*/
            fileName = new String(fileName.getBytes("UTF-8"), "ISO8859-1"); // firefox浏览器
        } else {
            fileName = URLEncoder.encode(fileName, "utf-8");
            //谷歌中空格变为+问题
            fileName = fileName.replaceAll("\\+","%20");
        }
        return fileName;
    }

    public boolean validateExcel(String filePath) {
        if (filePath == null || !(WDWUtil.isExcel2003(filePath) || WDWUtil.isExcel2007(filePath))) {
            errorMsg = "文件名不是excel格式";
            return false;
        }
        return true;
    }


    public static Workbook getWorkBook(MultipartFile file) throws IOException{
        //这样写  excel 能兼容03和07
        InputStream is = file.getInputStream();
        Workbook hssfWorkbook = null;
        try {
            hssfWorkbook = new HSSFWorkbook(is);
        } catch (Exception ex) {
            is =file.getInputStream();
            hssfWorkbook = new XSSFWorkbook(is);
        }
        return hssfWorkbook;
    }
}