package com.zgiot.zx.production.utils;

import java.time.*;
import java.time.format.DateTimeFormatter;
import java.util.Calendar;
import java.util.Date;

public class DateTimeUtils {
    /**
     * date 转 LocalDateTime
     *
     * @param date
     * @return
     */
    public static LocalDateTime dateToLocalDateTime(Date date) {

        // 获取时间实例

        Instant instant = date.toInstant();
        // 获取时间地区ID
        ZoneId zoneId = ZoneId.systemDefault();
        // 转换为LocalDate
        LocalDateTime localDateTime = instant.atZone(zoneId).toLocalDateTime();

        // 获得LocalDateTime时间戳(东八区)
        localDateTime.toEpochSecond(ZoneOffset.of("+8"));

        return localDateTime;
    }

    /**
     * date 转 LocalDate
     *
     * @param date
     * @return
     */
    public static LocalDate dateToLocalDate(Date date) {

        // 获取时间实例
        Instant instant = date.toInstant();
        // 获取时间地区ID
        ZoneId zoneId = ZoneId.systemDefault();
        // 转换为LocalDate
        return instant.atZone(zoneId).toLocalDate();
    }

    /**
     * localDateTime 转 Date
     *
     * @param localDateTime
     * @return
     */
    public static Date localDateTimeToDate(LocalDateTime localDateTime) {
        ZoneId zone = ZoneId.systemDefault();
        Instant instant = localDateTime.atZone(zone).toInstant();
        return Date.from(instant);
    }

    /**
     * localDate 转 Date
     *
     * @param localDateTime
     * @return
     */
    public static Date localDateToDate(LocalDate localDate) {
        ZoneId zone = ZoneId.systemDefault();
        Instant instant = localDate.atStartOfDay().atZone(zone).toInstant();
        return Date.from(instant);
    }

    //月初
    public static Date getBeginTimeOfMonth(int year , int month){
        Calendar c = Calendar.getInstance();
        c.set(Calendar.YEAR,year);
        c.set(Calendar.MONTH,month-1);
        c.set(Calendar.DAY_OF_MONTH,1);
        c.set(Calendar.HOUR_OF_DAY,0);
        c.set(Calendar.MINUTE,0);
        c.set(Calendar.SECOND,0);
        c.set(Calendar.MILLISECOND,0);
        return c.getTime();
    }

    //月末
    public static Date getEndTimeOfMonth(int year , int month){
        Calendar c = Calendar.getInstance();
        c.set(Calendar.YEAR,year);
        c.set(Calendar.MONTH,month-1);
        int lastDate = c.getActualMaximum(Calendar.DATE);
        c.set(Calendar.DAY_OF_MONTH,lastDate);
        c.set(Calendar.HOUR_OF_DAY,23);
        c.set(Calendar.MINUTE,59);
        c.set(Calendar.SECOND,59);
        c.set(Calendar.MILLISECOND,999);
        return c.getTime();
    }

    /**
     * 根据当前时间获取所在月份的开始和结束时间
     * @param today
     * @param isFirst
     * @return
     */
    public static LocalDateTime getStartOrEndDayOfMonth(LocalDateTime today, Boolean isFirst){
        if (today == null) {
            today = LocalDateTime.now();
        }
        LocalDate resultDate=LocalDate.now();
        Month month = today.getMonth();
        LocalDate localDate = today.toLocalDate();
        int length = month.length(localDate.isLeapYear());
        if (isFirst) {
            resultDate = LocalDate.of(localDate.getYear(), month, 1);
            return LocalDateTime.of(resultDate,LocalTime.MIN);
        } else {
            resultDate = LocalDate.of(localDate.getYear(), month, length);
            return LocalDateTime.of(resultDate,LocalTime.MAX);
        }
    }

    /**
     * @Author yuzhong
     * @Description 日期加上某小时后得到的新日期
     * @Date 2019/12/26
     * @Param [day, hour]
     * @return java.lang.String
     */
    public static Date addDateMinut(int hour) {
        Date date = new Date();
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        cal.add(Calendar.HOUR, hour);// 24小时制   
        date = cal.getTime();
        return date;
    }

    /**
     * @Author shizheng
     * @Description 返回查询月份
     * @Date 2020-06-15
     * @Param [Sring]
     * @return java.lang.String
     */
    public static String getTableSuffix(String queryDate){
        String[] index = queryDate.split("-");
        if(queryDate.indexOf("-")!=-1){
            //年月、年月日
            if(index[1].indexOf("0")!=-1    ){
                if(Integer.valueOf(index[1])>=10){
                    return index[0]+index[1];
                }else{
                    return index[0]+index[1].replace("0","");
                }
            }else{
                return index[0]+index[1];
            }
        }else{
            //年
            return null;
        }
    }

    public static String dataFormatter(LocalDateTime  queryDate){
        DateTimeFormatter dtf2 = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        String strDate2 = dtf2.format(queryDate);
        return  strDate2;
    }
}
